pub struct Chunk {
pub collection_index: u32,
pub start_state: Vec<u8>,
pub event_collection: Vec<u8>,
pub block_id: Vec<u8>,
pub total_computation_used: u64,
pub number_of_transactions: u32,
pub index: u64,
pub end_state: Vec<u8>,
pub execution_data_id: Vec<u8>,
pub state_delta_commitment: Vec<u8>,
pub service_event_count: u32,
}Fields
collection_index: u32start_state: Vec<u8>state when starting executing this chunk
event_collection: Vec<u8>Events generated by executing results
block_id: Vec<u8>Block id of the execution result this chunk belongs to
total_computation_used: u64total amount of computation used by running all txs in this chunk
number_of_transactions: u32number of transactions inside the collection
index: u64chunk index inside the ER (starts from zero)
end_state: Vec<u8>EndState inferred from next chunk or from the ER
execution_data_id: Vec<u8>state_delta_commitment: Vec<u8>a commitment over sorted list of register changes
service_event_count: u32number of service events emitted in this chunk (present in Protocol Version 2+)