Module execution

Module execution 

Modules

execution_api_client
Generated client implementations.
execution_api_server
Generated server implementations.
get_events_for_block_i_ds_response
Nested message and enum types in GetEventsForBlockIDsResponse.
get_transaction_error_messages_response
Nested message and enum types in GetTransactionErrorMessagesResponse.
get_transaction_execution_metrics_after_response
Nested message and enum types in GetTransactionExecutionMetricsAfterResponse.

Structs

BlockHeaderResponse
ExecuteScriptAtBlockIdRequest
ExecuteScriptAtBlockIdResponse
GetAccountAtBlockIdRequest
GetAccountAtBlockIdResponse
GetBlockHeaderByIdRequest
GetEventsForBlockIDsRequest
GetEventsForBlockIDsResponse
GetLatestBlockHeaderRequest
GetRegisterAtBlockIdRequest
GetRegisterAtBlockIdResponse
GetTransactionByIndexRequest
GetTransactionErrorMessageByIndexRequest
GetTransactionErrorMessageRequest
GetTransactionErrorMessageResponse
GetTransactionErrorMessagesByBlockIdRequest
GetTransactionErrorMessagesResponse
GetTransactionExecutionMetricsAfterRequest
The request for GetTransactionExecutionMetricsAfter
GetTransactionExecutionMetricsAfterResponse
The response for GetTransactionExecutionMetricsAfter The response contains the execution metrics for transactions in each block after the requested block height (block_height + 1). The execution node only keeps a limited number of blocks in memory, so the response may not contain metrics for all blocks. Only finalized and executed blocks will be in the response. The blocks are sorted by block height in descending order.
GetTransactionResultRequest
GetTransactionResultResponse
GetTransactionResultsResponse
GetTransactionsByBlockIdRequest
PingRequest
PingResponse