pub struct GetExecutionDataByBlockIdRequest {
pub block_id: Vec<u8>,
pub event_encoding_version: i32,
}Expand description
The request for GetExecutionDataByBlockID
Fields
block_id: Vec<u8>Block ID of the block to get execution data for.
event_encoding_version: i32Preferred event encoding version of the block events payload. Possible variants:
- CCF
- JSON-CDC
Implementations
Sourceimpl GetExecutionDataByBlockIdRequest
impl GetExecutionDataByBlockIdRequest
Sourcepub fn event_encoding_version(&self) -> EventEncodingVersion
pub fn event_encoding_version(&self) -> EventEncodingVersion
Returns the enum value of event_encoding_version, or the default if the field is set to an invalid enum value.
Sourcepub fn set_event_encoding_version(&mut self, value: EventEncodingVersion)
pub fn set_event_encoding_version(&mut self, value: EventEncodingVersion)
Sets event_encoding_version to the provided enum value.